@@ -49,14 +49,17 @@ G_BEGIN_DECLS
 
 typedef struct _ChamplainPolygonPrivate ChamplainPolygonPrivate;
 
-typedef struct {
+typedef struct _ChamplainPolygon        ChamplainPolygon;
+typedef struct _ChamplainPolygonClass   ChamplainPolygonClass;
+
+struct _ChamplainPolygon {
   GInitiallyUnowned parent;
   ChamplainPolygonPrivate *priv;
-} ChamplainPolygon;
+};
 
-typedef struct {
+struct _ChamplainPolygonClass {
   GInitiallyUnownedClass parent_class;
-} ChamplainPolygonClass;
+};
 
 GType champlain_polygon_get_type (void);
 
@@ -69,7 +72,7 @@ ChamplainPoint * champlain_polygon_insert_point (ChamplainPolygon *polygon,
     gdouble lat,
     gdouble lon,
     gint pos);
-void champlain_polygon_remove_point (ChamplainPolygon *self,
+void champlain_polygon_remove_point (ChamplainPolygon *polygon,
     ChamplainPoint *point);
 void champlain_polygon_clear_points (ChamplainPolygon *polygon);
 GList *champlain_polygon_get_points (ChamplainPolygon *polygon);
